go-alchemy-sdk

module
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 18, 2026 License: MIT

README

coverage

Go-Alchemy-Sdk

golang sdk for alchemy, inspired by https://github.com/alchemyplatform/alchemy-sdk-js.

This project aims to be a bridge between alchemy api and geth objects.

It supports not only Alchemy, but also other EVM chains.

Documentation

Features

🖧 easily switch EVM network | private network to Eth-Public Network.

⚙️ Designed to meet the needs of custom private chains, such as those requiring custom headers.

🧪 easily ut your web3.0 application or smart contract w/ simulated backend.

🪙 StableCoin native support

QuickStart

package main

import (
  "fmt"

  "github.com/poteto-go/go-alchemy-sdk/gas"
  "github.com/poteto-go/go-alchemy-sdk/types"
)

func main() {
  setting := gas.AlchemySetting{
    ApiKey:  "<api-key>",
    Network: types.EthMainnet,
  }

  alchemy := gas.NewAlchemy(setting)
  res, _ := alchemy.Core.GetBlockNumber()
  fmt.Println(res)
}

Caution

[!Caution] This project will have breaking changes until geth migration is done.

Major Milestone

  • Deploy Contract to Eth: v0.1.0
  • Smart-Contract Tx & call support: v0.2.0
  • Private Geth Support & ERC20.Transfer: v0.3.0
  • ERC20 method fully support: v0.4.0
  • SC(Stable Coin) method fully support: v0.6.0
  • NFT(ERC721) method fully support: v0.8.0
  • websocket support: rc0.10.0
  • stable release: rc1.0.0

Jump to